PASS is a large-scale image dataset that does not include any humans,
human parts, or other personally identifiable information.
It can be used for high-quality self-supervised pretraining while
significantly reducing privacy concerns.

PASS contains 1,439,589 images without any labels sourced from YFCC-100M.

All images in this dataset are licenced under the CC-BY licence, as is the
dataset itself.
For YFCC-100M see  http://www.multimediacommons.org/.
